/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { IKey } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
import { IKnowledgeBase } from './../knowledge-bases/knowledge-base';
import { DataSourceAssociationProps, DataSourceNew, DataSourceType } from './base-data-source';
/**
 * Interface to add a new CustomDataSource to an existing KB
 */
export interface CustomDataSourceAssociationProps extends DataSourceAssociationProps {
}
/**
 * Interface to create a new Custom Data Source object.
 */
export interface CustomDataSourceProps extends CustomDataSourceAssociationProps {
    /**
     * The knowledge base to associate with the data source.
     */
    readonly knowledgeBase: IKnowledgeBase;
}
/**
 * Sets up a custom Data Source to be added to a knowledge base.
 */
export declare class CustomDataSource extends DataSourceNew {
    /**
     * The unique identifier of the data source.
     * @example 'JHUEVXUZMU'
     */
    readonly dataSourceId: string;
    /**
     * The type of data source.
     */
    readonly dataSourceType: DataSourceType;
    /**
     * The name of the data source.
     */
    readonly dataSourceName: string;
    /**
     * The knowledge base associated with the data source.
     */
    readonly knowledgeBase: IKnowledgeBase;
    /**
     * The KMS key to use to encrypt the data source.
     */
    readonly kmsKey?: IKey;
    /**
     * The Data Source cfn resource.
     */
    private readonly __resource;
    constructor(scope: Construct, id: string, props: CustomDataSourceProps);
}
